@@ -18,3 +18,7 @@ def true_if_none(value):
 
 def to_boolean(value):
     return value if isinstance(value, bool) else False
+
+
+def value_or_default(value, default):
+    return value if value is not None else default
